@@ -1,7 +1,7 @@
 
 class DictManipulate:
 
-    def findkeys(self,node, kv):
+    def findkeyValue(self,node, kv):
         if isinstance(node, list):
             for i in node:
                 for x in self.findkeys(i, kv):
@@ -11,10 +11,10 @@ class DictManipulate:
             if kv in node:
                 yield node[kv]
             for j in node.values():
-                for x in self.findkeys(j, kv):
+                for x in self.findkeyValue(j, kv):
                     yield x
 
-    def findValue(self,d, search_pattern, prev_datapoint_path=''):
+    def KeyPathByValue(self,d, search_pattern, prev_datapoint_path=''):
         output = []
         search_pattern = str(search_pattern)
         current_datapoint = d
@@ -27,7 +27,7 @@ class DictManipulate:
                     output.append(c)
                 c = current_datapoint_path
                 c+="['"+dkey+"']"
-                for i in self.findValue(current_datapoint[dkey], search_pattern, c):
+                for i in self.KeyPathByValue(current_datapoint[dkey], search_pattern, c):
                     output.append(i)
         elif type(current_datapoint) is list:
             for i in range(0, len(current_datapoint)):
@@ -37,7 +37,7 @@ class DictManipulate:
                     output.append(i)
                 c = current_datapoint_path
                 c+="["+ str(i) +"]"
-                for i in self.findValue(current_datapoint[i], search_pattern, c):
+                for i in self.KeyPathByValue(current_datapoint[i], search_pattern, c):
                     output.append(i)
         elif search_pattern in str(current_datapoint):
             c = current_datapoint_path
@@ -71,19 +71,3 @@ class DictManipulate:
             flag = 1
         return res
 
-
-res = DictManipulate().findkeys(d,"id")
-print(list(res),"res")
-res1 = DictManipulate().findValue(d,"23")
-print(list(res1),"res1")
-res2 = DictManipulate().flatten(d)
-print(res2,"res2")
-res3 = DictManipulate().splitDict(d,2)
-print(res3,"res3")
-
-
-
-
-
-
-
